RequestX class

Available extensions

Constructors

RequestX(String _authority)
RequestX.fromUrl(String _url)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

body(Map<String, dynamic> body) RequestX

Available on RequestX, provided by the Fluent extension

decodeResponseBodyBytes() RequestX

Available on RequestX, provided by the Fluent extension

delete() RequestX

Available on RequestX, provided by the Fluent extension

doIsolateRequest() Future<Validation>

Available on RequestX, provided by the Fluent extension

Esegue la richiesta in un isolate. Se è stata impostata la cache tramite useCache tenta di recuperare il valore dalla cache. Se non esiste, esegue la chiamata e poi salva il valore nella cache usando come id l'url della chiamata.
doRequest<T>() Future<Validation<T>>

Available on RequestX, provided by the Fluent extension

La doRequestfa la chiamata senza isolate Per eseguire la chiamata in un isolate, usare doIsolateRequest()._authoritySe è stata impostata la cache tramite useCache tenta di recuperare il valore dalla cache. Se non esiste, esegue la chiamata e poi salva il valore nella cache usando come id l'url della chiamata.
enableLog(bool enable) RequestX

Available on RequestX, provided by the Fluent extension

get() RequestX

Available on RequestX, provided by the Fluent extension

getResponseBytes() RequestX

Available on RequestX, provided by the Fluent extension

getUri() Uri
headers(Map<String, String> headers) RequestX

Available on RequestX, provided by the Fluent extension

isHttp() RequestX

Available on RequestX, provided by the Fluent extension

jsonDelete() RequestX

Available on RequestX, provided by the Fluent extension

jsonGet() RequestX

Available on RequestX, provided by the Fluent extension

jsonPatch() RequestX

Available on RequestX, provided by the Fluent extension

jsonPost() RequestX

Available on RequestX, provided by the Fluent extension

jsonPut() RequestX

Available on RequestX, provided by the Fluent extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
params(Map<String, dynamic> params) RequestX

Available on RequestX, provided by the Fluent extension

path(String path) RequestX

Available on RequestX, provided by the Fluent extension

post() RequestX

Available on RequestX, provided by the Fluent extension

put() RequestX

Available on RequestX, provided by the Fluent extension

toString() String
A string representation of this object.
inherited
trustBadCertificatesInDebug(bool trust) RequestX

Available on RequestX, provided by the Fluent extension

useCache({Duration duration = const Duration(seconds: 30)}) RequestX

Available on RequestX, provided by the Fluent extension

Usare per salvare il rilultato nella cache o riottenerlo alla prossiam chiamata. L'id della cache è l'url di chiamata

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

clearCache() → void